import { UnorderedListOutlined } from '@ant-design/icons';
import { Button, Modal } from 'antd';
import React from 'react';
import '../../tencentAdPutIn/index.less';

/**
 * UserInfo是一个React函数组件，用于展示用户信息页面
 * 该组件没有参数和返回值，它通过返回一个包含用户信息页面的JSX元素来工作
 * 选择使用函数组件而不是类组件是因为用户信息页面通常不涉及复杂的组件状态管理
 * 此外，通过使用函数组件，可以利用React的Hooks特性，进一步简化组件逻辑
 */
const UserInfo: React.FC<{ createTime: string, groupMemberCnt: number, userInfoList: { userId: string, userName: string, msg: string, state: 0 | 1 }[] }> = ({ createTime, groupMemberCnt, userInfoList }) => {
    // 返回一个包含用户信息页面布局的JSX元素
    // 这里使用了简单的HTML元素来构建页面结构，包括一个标题和一段描述

    /************************************/
    const [visible, setVisible] = React.useState<boolean>(false);
    /************************************/

    return <>
        <Button icon={<UnorderedListOutlined />} style={{ border: 'none', fontSize: 12 }} size='small' onClick={() => setVisible(true)}>详情</Button>
        {visible && <Modal
            title={<strong>客服组详情</strong>}
            open={visible}
            onCancel={() => setVisible(false)}
            footer={null}
            className='modalResetCss'
        >
            <p>创建时间：{createTime}</p>
            <p>客服认识：{groupMemberCnt}</p>
            <div style={{ display: 'flex' }}>
                <p>已选客服：</p>
                <div>{userInfoList.map(item => {
                    return <div key={item.userId} style={item.state === 1 ? { color: 'red' } : {}}>{item.userName || item.msg + `（${item.userId}）`}</div>
                })}</div>
            </div>
        </Modal>}
    </>;
};

export default React.memo(UserInfo);